<?php

namespace App\Http\Controllers;

use App\Models\Category;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class CategoryController extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $categories = Category::query();

            return DataTables::of($categories)

                ->addColumn('image', function ($category) {
                    return '<img src="' . asset($category->image) . '" alt="No Category Image" class="w-32">';
                })
                ->addColumn('action', function ($category) {
                    return '<a href="' . route('category.edit', $category->id) . '" class="text-black"><i class="text-4xl bx bx-edit"></i></a>
                            <form action="' . route('category.destroy', $category->id) . '" method="POST" style="display: inline-block;">
                                ' . csrf_field() . '
                                ' . method_field('DELETE') . '
                                <button type="submit" class="text-red-500"><i class="text-4xl bx bx-trash"></i></button>
                            </form>
                           ';
                })
                ->rawColumns(['image', 'action'])
                ->make(true);
        }

        return view('admin.category.index'); // Ensure this view exists
    }

    public function create()
    {

        return view('admin.category.create');
    }

    public function store(Request $request)
    {
        // Validate the request
        $request->validate([
            'name' => 'required|string|max:255',
            'image' => 'required|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);


        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
        }

        // Create the banner
        $category = Category::create([
            'name' => $request->input('name'),
            'image' => $image, // Pass the image path or null
        ]);

        return redirect()->route('category.index')->with('success', 'Category created successfully!');
    }

    public function edit($id)
    {
        $category = Category::findOrFail($id);
        return view('admin.category.edit', compact('category'));
    }

    public function update(Request $request, $id)
    {
        // Validate the request
        $request->validate([
            'name' => 'required|string|max:255',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);

        // Find the banner by ID
        $category = Category::findOrFail($id);
        $category->name = $request->input('name');

        // Handle the image upload
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
            $category->image = $image;
        }

        // Save the updated banner
        $category->save();

        // Redirect with success message
        return redirect()->route('category.index')->with('success', 'Category updated successfully.');
    }

   public function destroy($id)
    {
        $category = Category::findOrFail($id);
    
        // Check if the category has related products
        if ($category->products()->exists()) {
            return redirect()->back()->with('errors', 'Cannot delete category with associated products.');
        }
        
         if ($category->blogs()->exists()) {
            return redirect()->back()->with('errors', 'Cannot delete category with associated blogs.');
        }
    
        // Delete the category
        $category->delete();
    
        return redirect()->back()->with('success', 'Category deleted successfully');
    }


}
