<?php

namespace App\Http\Controllers;

use App\Models\ContactUs;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class ContactUsController extends Controller
{

    public function index()
    {
        if (request()->ajax()) {
            $contact_us = ContactUs::query();

            return DataTables::of($contact_us)
                ->addColumn('action', function ($contactus) {
                    return '
                            <form action="' . route('contactus.destroy', $contactus->id) . '" method="POST" style="display: inline-block;">
                                ' . csrf_field() . '
                                ' . method_field('DELETE') . '
                                <button type="submit" class="text-red-500"><i class="text-4xl bx bx-trash"></i></button>
                            </form>
                           ';
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        return view('admin.contactus.index'); // Ensure this view exists
    }



    public function store(Request $request)
    {
        // Validate the request
        $request->validate([
            'full_name' => 'required',
            'email' => 'required|email',
            'mobile_number' => 'nullable|digits:11',
            'subject' => 'required',
            'message' => 'required',
        ]);


        // Create the news item
        ContactUs::create([
            'full_name' => $request->input('full_name'),
            'email' => $request->input('email'),
            'mobile_number' => $request->input('mobile_number'),
            'subject' => $request->input('subject'),
            'message' => $request->input('message'),
        ]);

        return redirect()->back()->with('success', 'Success!')->with('message', 'Your message has been submitted successfully!')->with('message2', 'We will get back to you soon')->with('thank you', 'Thank you for contacting us!');
    }

    public function destroy($id)
    {
        $contactus = ContactUs::findOrFail($id);
        $contactus->delete();

        return redirect()->back()->with('success', 'Message deleted successfully.');
    }
}
