<x-app-layout>
    <div class="container max-w-lg p-6 mx-auto bg-white rounded-lg shadow-lg">
        <h1 class="mb-4 text-2xl font-bold">Edit Blogs</h1>

        <form action="{{ route('blogs.update', $blogs->id) }}" method="POST" enctype="multipart/form-data">
            @csrf
            @method('PUT')

            <div class="mb-4">
                <label for="category_name" class="block text-gray-700">Category:</label>
            
                <!-- Dropdown for selecting or adding a category -->
                <select id="category_name" name="category_name" class="w-full p-2 border border-gray-300 rounded" required>
                    <option value="">Select Category</option>
                    
                    <!-- Existing categories (you can loop through categories dynamically) -->
                    @foreach($categories as $category)
                        <option value="{{ $category->name }}" 
                            {{ old('category_name', $blogs->category->name) == $category->name ? 'selected' : '' }}>
                            {{ $category->name }}
                        </option>
                    @endforeach
            
                    <!-- Option for adding a new category -->
                    <option value="add_new">Add New Category</option>
                </select>
            
                <!-- Input field for new category, initially hidden -->
                <input type="text" id="new_category" name="new_category" class="w-full p-2 border border-gray-300 rounded mt-2 hidden" 
                       value="{{ old('new_category') }}" placeholder="Enter new category">
            
                @error('category_name')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>
            
            <script>
                // Show the new category input field when "Add New Category" is selected
                document.getElementById('category_name').addEventListener('change', function() {
                    var newCategoryInput = document.getElementById('new_category');
                    if (this.value === 'add_new') {
                        newCategoryInput.classList.remove('hidden');  // Show the input
                        newCategoryInput.setAttribute('required', 'required');  // Make it required
                    } else {
                        newCategoryInput.classList.add('hidden');  // Hide the input
                        newCategoryInput.removeAttribute('required');  // Remove the required attribute
                    }
                });
            </script>


            <div class="mb-4">
                <label for="title" class="block text-gray-700">Title:</label>
                <input type="text" required id="title" name="title" value="{{ $blogs->title }}"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('title')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="mb-4">
                <label for="description" class="block text-gray-700">Description:</label>
                <textarea id="description" name="description" class="w-full p-2 border border-gray-300 rounded">{{ $blogs->description }}</textarea>
                @error('description')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="mb-4">
                <label for="image" class="block text-gray-700">Image (optional):</label>
                <input type="file" id="image" name="image" class="w-full p-2 border border-gray-300 rounded">
                @error('image')
                <span class="text-red-500">{{ $message }}</span>
                @enderror

                @if ($blogs->image)
                <div class="mt-2">
                    <label class="block text-gray-700">Current Image:</label>
                    <img src="{{ asset($blogs->image) }}" alt="Current Image"
                        class="w-full h-auto max-w-xs border border-gray-300 rounded">
                </div>
                @endif
            </div>

            <button type="submit" class="px-12 py-2 text-white bg-black rounded-full">Update</button>
        </form>
    </div>



    <script src="https://cdn.ckeditor.com/4.16.0/standard/ckeditor.js"></script>

    <script>
        CKEDITOR.replace('description');
    </script>
</x-app-layout>