<x-app-layout>
    <div class="container max-w-4xl p-6 mx-auto bg-white rounded-lg shadow-lg">
        <h1 class="mb-4 text-2xl font-bold">Edit Product</h1>

        <form action="{{ route('products.update', $product->id) }}" method="POST" enctype="multipart/form-data" class="grid grid-cols-1 gap-8 md:grid-cols-2">
            @csrf
            @method('PUT')

            <div class="mb-4">
                <label for="category_name" class="block text-gray-700">Category:</label>

                <!-- Dropdown for selecting or adding a category -->
                <select id="category_name" name="category_name" class="w-full p-2 border border-gray-300 rounded" required>
                    <option value="">Select Category</option>

                    <!-- Existing categories (you can loop through categories dynamically) -->
                    @foreach($categories as $category)
                    <option value="{{ $category->name }}"
                        {{ old('category_name', $product->category->name) == $category->name ? 'selected' : '' }}>
                        {{ $category->name }}
                    </option>
                    @endforeach

                    <!-- Option for adding a new category -->
                    <option value="add_new">Add New Category</option>
                </select>

                <!-- Input field for new category, initially hidden -->
                <input type="text" id="new_category" name="new_category" class="hidden w-full p-2 mt-2 border border-gray-300 rounded"
                    value="{{ old('new_category') }}" placeholder="Enter new category">

                @error('category_name')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <script>
                // Show the new category input field when "Add New Category" is selected
                document.getElementById('category_name').addEventListener('change', function() {
                    var newCategoryInput = document.getElementById('new_category');
                    if (this.value === 'add_new') {
                        newCategoryInput.classList.remove('hidden'); // Show the input
                        newCategoryInput.setAttribute('required', 'required'); // Make it required
                    } else {
                        newCategoryInput.classList.add('hidden'); // Hide the input
                        newCategoryInput.removeAttribute('required'); // Remove the required attribute
                    }
                });
            </script>

            <div class="mb-4">
                <label for="brand_name" class="block text-gray-700">Brand:</label>

                <!-- Dropdown for selecting or adding a brand -->
                <select id="brand_name" name="brand_name" class="w-full p-2 border border-gray-300 rounded" required>
                    <option value="">Select Brand</option>

                    <!-- Existing brands (you can loop through brands dynamically) -->
                    @foreach($brands as $brand)
                    <option value="{{ $brand->brand_name }}"
                        {{ old('brand_name', $product->brand->brand_name) == $brand->brand_name ? 'selected' : '' }}>
                        {{ $brand->brand_name }}
                    </option>
                    @endforeach

                    <!-- Option for adding a new brand -->
                    <option value="add_new">Add New Brand</option>
                </select>

                <!-- Input field for new brand, initially hidden -->
                <input type="text" id="new_brand" name="new_brand" class="hidden w-full p-2 mt-2 border border-gray-300 rounded"
                    value="{{ old('new_brand') }}" placeholder="Enter new brand">

                @error('brand_name')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <script>
                // Show the new brand input field when "Add New Brand" is selected
                document.getElementById('brand_name').addEventListener('change', function() {
                    var newBrandInput = document.getElementById('new_brand');
                    if (this.value === 'add_new') {
                        newBrandInput.classList.remove('hidden'); // Show the input
                        newBrandInput.setAttribute('required', 'required'); // Make it required
                    } else {
                        newBrandInput.classList.add('hidden'); // Hide the input
                        newBrandInput.removeAttribute('required'); // Remove the required attribute
                    }
                });
            </script>


            <div class="md:col-span-2">
                <label for="name" class="block text-gray-700">Name:</label>
                <input type="text" required value="{{ old('name', $product->name) }}" id="name" name="name"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('name')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="">
                <label for="price" class="block text-gray-700">Price:</label>
                <input type="number" required value="{{ old('price', $product->price) }}" id="price" name="price"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('price')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="">
                <label for="stock" class="block text-gray-700">Stock:</label>
                <input type="number" required value="{{ old('stock', $product->stock) }}" id="stock" name="stock"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('stock')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="md:col-span-2">
                <label for="description" class="block text-gray-700">Description:</label>
                <textarea id="description" name="description" class="w-full p-2 border border-gray-300 rounded">{{ old('description', $product->description) }}</textarea>
                @error('description')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="md:col-span-2">
                <label for="shipping_and_returns" class="block text-gray-700">Shipping and Returns:</label>
                <textarea id="shipping_and_returns" name="shipping_and_returns" class="w-full p-2 border border-gray-300 rounded">{{ old('shipping_and_returns', $product->shipping_and_returns) }}</textarea>
                @error('shipping_and_returns')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <!-- Display existing images with delete option -->
            <div class="md:col-span-2">
                <h4 class="text-gray-700">Existing Images:</h4>
                @foreach($product->images as $image)
                <div class="flex items-center my-2">
                    <img src="{{ asset($image->image) }}" alt="Product Image" class="w-20 h-20 mr-4 rounded">
                    <label class="text-gray-700">
                        <input type="checkbox" name="delete_image_ids[]" value="{{ $image->id }}">
                        Delete this image
                    </label>
                </div>
                @endforeach
            </div>

            <!-- Upload new images -->
            <div class="md:col-span-2">
                <label for="image[]" class="block text-gray-700">Add New Images:</label>
                <input type="file" multiple id="image[]" name="image[]"
                    accept="image/webp,image/jpg,image/jpeg,image/png,image/gif"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('image')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <button type="submit" class="px-12 py-2 text-white bg-black rounded-full">Update Product</button>
        </form>
    </div>

    <script src="https://cdn.ckeditor.com/4.16.0/standard/ckeditor.js"></script>
    <script>
        CKEDITOR.replace('description');
        CKEDITOR.replace('shipping_and_returns');
    </script>
</x-app-layout>