<!-- contact_us.blade.php -->
@extends('layouts.main-app')

@section('title', 'Products')

@section('content')

@include('layouts.navbar')

<div class="bg-gray-100">
    <div class="container max-w-screen-xl px-4 py-8 mx-auto">
        <div class="grid grid-cols-1 gap-8 overflow-hidden md:grid-cols-3">
            <div data-aos="fade-right"
                data-aos-duration="1500">
                @include('layouts.shop_filter')
            </div>
            <div data-aos="fade-left"
                data-aos-duration="1500" class="space-y-8 md:col-span-2">
                <div class="grid grid-cols-1 gap-8 md:grid-cols-2">
                    <div class="flex flex-col gap-4">
                        <div class="relative w-full zoom-container">
                            <!-- Main image that will be zoomed -->
                            <img id="main-image" src="{{ $product_details->images->isNotEmpty() ? asset($product_details->images->first()->image) : asset('images/homepage/logo-header.webp') }}" alt="Main Image" class="w-full h-auto">

                            <!-- Zoom lens that will display the zoomed area -->
                            <div id="zoom-lens" class="zoom-lens"></div>
                        </div>

                        <div>
                            <div class="relative w-full">
                                <div class="relative swiper product-slide-carousel swiper-container">
                                    <div class="mb-16 swiper-wrapper">
                                        @foreach ($product_details->images as $image)
                                        <div class="swiper-slide">
                                            <div>
                                                <img onclick="updateMainImage(this)" class="p-2 bg-white cursor-pointer" src="{{ asset($image->image) }}" alt="Thumbnail">
                                            </div>
                                        </div>
                                        @endforeach
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="space-y-4">
                        <h1 class="text-2xl font-semibold">{{$product_details->name}}</h1>
                        <h1 class="text-[#cf000f] font-semibold">₱{{ number_format($product_details->price, 2) }}</h1>
                        <ul>
                            <li><span class="font-bold">Brand:</span> {{$product_details->brand->brand_name}}</li>
                            <li><span class="font-bold">Category:</span> {{$product_details->category->name}}</li>
                            <li><span class="font-bold">Stock:</span> {{$product_details->stock}}</li>
                        </ul>
                        <div class="space-y-4">
                            <h1>Quantity:</h1>


                            <div class="flex items-center space-x-2">
                                <button type="button"
                                    class="border border-[#cf000f] rounded-full text-[#cf000f] h-8 w-8 bg-white"
                                    onclick="decrementQuantity({{ $product_details->id }})">-</button>
                                <span id="quantity-display-{{ $product_details->id }}" class="px-4">1</span>
                                <button type="button"
                                    class="border border-[#cf000f] rounded-full text-[#cf000f] h-8 w-8 bg-white"
                                    onclick="incrementQuantity({{ $product_details->id }})">+</button>
                            </div>

                            <div class="flex flex-wrap items-center gap-4">

                                <input type="hidden" name="product_id" id="product-id-{{ $product_details->id }}" value="{{ $product_details->id }}">
                                <input type="hidden" id="quantity-{{ $product_details->id }}" name="quantity" value="1">

                                <!-- Add to Cart Button -->
                                <button type="submit" onclick="addToCart({{ $product_details->id }})" class="bg-[#cf000f] flex text-white rounded-full px-6 py-2">Add to Cart <img class="pl-4" src="{{asset('images/homepage/icon-addtocart.webp')}}" alt=""></button>


                                @if(Auth::check())
                                <button type="submit" onclick="addToWishlist({{ $product_details->id }}, {{ Auth::id() }})" class="flex px-6 py-2 border border-[#cf000f] bg-white rounded-full">
                                    <img class="pr-4" src="{{asset('images/homepage/icon-addtowishlist.webp')}}" alt="">
                                    Add to Wishlist </button>
                                @else
                                <a href="{{url('wishlist')}}">
                                    @csrf
                                    <button type="submit" class="flex px-6 py-2 border border-[#cf000f] bg-white rounded-full">
                                        <img class="pr-4" src="{{asset('images/homepage/icon-addtowishlist.webp')}}" alt="">
                                        Add to Wishlist </button>
                                </a>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>
                <div class="grid grid-cols-1 lg:grid-cols-3">
                    <div
                        class="py-2 text-center bg-white border border-black cursor-pointer"
                        onclick="showTab('description')">
                        <h1 class="text-[#cf000f]">PRODUCT DETAILS</h1>
                    </div>
                    <div
                        class="py-2 text-center bg-white border border-black cursor-pointer"
                        onclick="showTab('reviews')">
                        <h1 class="text-[#cf000f]">REVIEWS</h1>
                    </div>
                    <div
                        class="py-2 text-center bg-white border border-black cursor-pointer"
                        onclick="showTab('shipping_and_returns')">
                        <h1 class="text-[#cf000f]">SHIPPING AND RETURNS</h1>
                    </div>
                </div>

                <div id="description" class="tab-content">
                    {!! $product_details->description !!}
                </div>

                <div id="reviews" class="hidden tab-content">
                    <p></p>
                </div>

                <div id="shipping_and_returns" class="hidden tab-content">
                    {!! $product_details->shipping_and_returns !!}
                </div>

                <script>
                    function showTab(tabId) {
                        // Hide all tab content
                        document.querySelectorAll('.tab-content').forEach((el) => el.classList.add('hidden'));

                        // Show the selected tab content
                        document.getElementById(tabId).classList.remove('hidden');
                    }
                </script>


            </div>
        </div>
        <hr data-aos="fade-up" data-aos-duration="1500" class="border-[#cf000f] my-4">
        <div data-aos="fade-up" data-aos-duration="1500" class="flex flex-wrap items-center justify-between">
            <h1 class="text-[#cf000f] font-bold">YOU MAY ALSO LIKE</h1>
            <a href="{{url('shop')}}"> <button class="text-[#cf000f] flex items-center">View All Products <i class='text-2xl bx bx-chevron-right'></i></button></a>

        </div>
        <div data-aos="fade-up" data-aos-duration="1500">
            <div class="relative w-full">
                <div class="relative swiper multiple-slide-carousel swiper-container">
                    <div class="mb-16 swiper-wrapper">

                        @php
                        $products = $products->shuffle(); // Shuffle the collection
                        @endphp

                        @foreach ($products as $product)
                        @if ($product->id != $product_details->id) <!-- Check if the product ID is different from product_details ID -->
                        <div class="swiper-slide">
                            <div class="h-[26rem] group hover:shadow-xl hover:bg-white group-regular-product-{{ $product->id }}">

                                <div class="flex flex-col w-full">
                                    <a href="{{ url('product_details', $product->id) }}">
                                        <img class="object-contain w-full p-4 bg-white h-60"
                                            src="{{ $product->images->isNotEmpty() ? asset($product->images->first()->image) : asset('images/homepage/logo-header.webp') }}"
                                            alt="">
                                    </a>
                                    <div class="p-2 ">
                                        <div class="flex justify-between ">
                                            <div class="truncate ">
                                                <h1 class="inline-block w-full text-sm" style="max-width: 130px; white-space: nowrap; overflow: hidden; text-overflow: ellipsis;" title="{{ $product->name }}">
                                                    {{ $product->name }}
                                                </h1>
                                            </div>
                                            <div>
                                                @if (Auth::check())
                                                <button onclick="addToWishlist({{ $product->id }}, {{ Auth::id() }})" class="focus:outline-none">
                                                    <img src="{{ asset('images/homepage/icon-addtowishlist.webp') }}" alt="Add to Wishlist">
                                                </button>
                                                @else
                                                <a href="{{ url('wishlist') }}">
                                                    <button type="button" class="focus:outline-none">
                                                        <img src="{{ asset('images/homepage/icon-addtowishlist.webp') }}" alt="Add to Wishlist">
                                                    </button>
                                                </a>
                                                @endif
                                            </div>
                                        </div>

                                        <p class="font-bold text-[#cf000f]">₱{{ number_format($product->price, 2) }}</p>
                                    </div>
                                </div>


                                <div class="flex flex-col items-center hidden py-2 space-y-2 group-hover:flex">
                                    <input type="hidden" id="product-id-{{ $product->id }}" value="{{ $product->id }}">
                                    <input type="hidden" id="quantity-{{ $product->id }}" value="1">

                                    <!-- Quantity controls -->
                                    <div class="flex items-center justify-center space-x-2">
                                        <button type="button" class="border border-[#cf000f] rounded-full text-[#cf000f] h-8 w-8 bg-white" onclick="decrementQuantity({{ $product->id }})">-</button>
                                        <span id="quantity-display-{{ $product->id }}" class="px-4">1</span>
                                        <button type="button" class="border border-[#cf000f] rounded-full text-[#cf000f] h-8 w-8 bg-white" onclick="incrementQuantity({{ $product->id }})">+</button>
                                    </div>

                                    <!-- Add to Cart Button -->
                                    <button type="button" onclick="addToCart({{ $product->id }})" class="bg-[#cf000f] text-white flex justify-between items-center rounded-full px-6 py-2 text-xs group-hover:flex">
                                        Add to Cart<img class="pl-4" src="{{ asset('images/homepage/icon-addtocart.webp') }}" alt="Add to Cart">
                                    </button>
                                </div>
                            </div>
                        </div>
                        @endif
                        @endforeach
                    </div>
                </div>
            </div>
        </div>


    </div>
</div>


@include('layouts.footer')
@endsection