<!-- contact_us.blade.php -->
@extends('layouts.main-app')

@section('title', 'Register')

@section('content')

@include('layouts.navbar')

<div class="bg-gray-100">
    <div class="container max-w-screen-lg px-4 py-8 mx-auto">
        <h1 class="text-[#cf000f] font-bold text-center pb-8 text-2xl">Create Your Account</h1>

        <div class="flex flex-col justify-between col-span-2 bg-white md:flex-row rounded-3xl">

            <form method="POST" action="{{ route('register.submit') }}">
                @csrf
                <div class="flex flex-col justify-center p-8 space-y-4 text-sm">
                    <h1 class="pb-8 text-lg font-bold text-black">Get started with your online orders, track prescriptions, and enjoy exclusive discounts.</h1>
                    <div>
                        <label for="name">Full Name</label>
                        <input type="text" id="name" name="name" class="border border-[#cf000f] w-full rounded-full text-sm  p-2" placeholder="Enter your full name" value="{{ old('name') }}">
                        @error('name')<span class="text-sm text-red-500">{{ $message }}</span>@enderror
                    </div>
                    <div class="grid grid-cols-1 gap-4 md:grid-cols-2">
                        <div>
                            <label for="email">Email Address</label>
                            <input type="email" id="email" name="email" class="border border-[#cf000f] w-full rounded-full text-sm  p-2" placeholder="Enter a valid email address" value="{{ old('email') }}">
                            @error('email')<span class="text-sm text-red-500">{{ $message }}</span>@enderror
                        </div>

                        <div>
                            <label for="contact_number">Mobile Number</label>
                            <input type="number" id="contact_number" name="contact_number" class="border border-[#cf000f] w-full rounded-full text-sm  p-2" placeholder="Enter your mobile number" value="{{ old('contact_number') }}">
                            @error('contact_number')<span class="text-sm text-red-500">{{ $message }}</span>@enderror
                        </div>

                        <div>
                            <label for="password">Password</label>
                            <input type="password" id="password" name="password" class="border border-[#cf000f] w-full rounded-full text-sm  p-2" placeholder="Enter a strong password">
                            @error('password')<span class="text-sm text-red-500">{{ $message }}</span>@enderror
                        </div>

                        <div>
                            <label for="confirm_password">Confirm Password</label>
                            <input type="password" id="confirm_password" name="password_confirmation" class="border border-[#cf000f] w-full rounded-full text-sm  p-2" placeholder="Re-enter your password">
                        </div>

                        <div>
                            <label for="birthday">Birthday</label>
                            <input type="date" id="birthday" name="birthday" class="border border-[#cf000f] w-full rounded-full text-sm  p-2" value="{{ old('birthday') }}">
                            @error('birthday')<span class="text-sm text-red-500">{{ $message }}</span>@enderror
                        </div>

                        <div>
                            <label for="gender">Gender</label>
                            <div class="flex flex-wrap items-center col-span-2 gap-4">
                                <div class="flex items-center space-x-2">
                                    <input type="radio" id="gender" name="gender" value="Male" class="rounded-full border border-[#cf000f]" {{ old('gender') == 'Male' ? 'checked' : '' }}>
                                    <label for="gender">Male</label>
                                </div>

                                <div class="flex items-center space-x-2">
                                    <input type="radio" id="gender" name="gender" value="Female" class="rounded-full border border-[#cf000f]" {{ old('gender') == 'Female' ? 'checked' : '' }}>
                                    <label for="gender">Female</label>
                                </div>

                                <div class="flex items-center space-x-2">
                                    <input type="radio" id="gender" name="gender" value="Other" class="rounded-full border border-[#cf000f]" {{ old('gender') == 'Other' ? 'checked' : '' }}>
                                    <label for="gender">Other</label>
                                </div>
                            </div>
                            @error('gender')<span class="text-sm text-red-500">{{ $message }}</span>@enderror
                        </div>
                    </div>

                    <div class="flex items-start space-x-2">
                        <input id="checkbox-table-search-1" type="checkbox" class="w-4 h-4 text-blue-600 bg-white border-black rounded" required>
                        <label for="checkbox-table-search-1" class="text-sm text-black">I agree to the <span class="font-bold text-[#cf000f]">Terms of Service</span> and <span class="font-bold text-[#cf000f]">Privacy Policy</span></label>
                    </div>

                    <div>
                        <button type="submit" class="bg-[#cf000f] text-white w-full rounded-full py-3 text-md">Create Account</button>
                    </div>

                    <div class="text-center text-gray-500 ">
                        Already have an account? <a href="{{ url('login') }}"><span class="font-bold text-[#cf000f]">Login</span></a>
                    </div>
                </div>
            </form>

            <div>
                <img class="object-cover w-full h-full" src="{{asset('images/img-overlay.png')}}" alt="">
            </div>
        </div>
    </div>
</div>


@if(session()->has('success'))
<div id="loginModal" class="fixed inset-0 flex items-center justify-center bg-gray-800 bg-opacity-50">
    <div class="w-full p-8 space-y-4 bg-white lg:w-1/3 rounded-3xl">
        <div class="flex justify-center">
            <img src="{{asset('images/shop/icon-check.png')}}" alt="">
        </div>
        <p class="mb-4 text-xl text-center">{{ session('success') }}</p>
        <p class="mb-4 text-center text-gray-400">You can now login with your account.</p>
        <div>
            <a href="{{ route('login') }}" class="bg-[#cf000f] text-white w-full rounded-full py-2 text-center block">Proceed to Login</a>
        </div>
    </div>
</div>
@endif

@include('layouts.footer')
@endsection