<!-- contact_us.blade.php -->
@extends('layouts.main-app')

@section('title', 'Home')

@section('content')

@include('layouts.navbar')

<div class="container max-w-screen-xl px-4 py-8 mx-auto">
    @if ($errors->any())
    <div class="p-4 mb-4 text-white bg-red-500 rounded">
        <ul>
            @foreach ($errors->all() as $error)
            <li>{{ $error }}</li>
            @endforeach
        </ul>
    </div>
    @endif
    <h1 class="text-[#cf000f] text-xl font-semibold">Welcome, John!</h1>
    <div class="grid gap-12 lg:grid-cols-3">
        <div class="space-y-4 lg:col-span-2">
            <div class="grid grid-cols-1 gap-8 md:grid-cols-2">
                <div class="border rounded-lg border-[#cf000f]  divide-x-2 divide-[#cf000f] p-4 h-32 flex justify-center space-x-12">
                    <h1 class="py-8 text-2xl font-bold"> {{ number_format(Auth::user()->reward_points, 0) }}</h1>
                    <p class="px-2 text-lg">Reward Points</p>
                </div>
                <div class="border rounded-lg border-[#cf000f]  divide-x-2 divide-[#cf000f] p-4 h-32 flex justify-center space-x-12">
                    <h1 class="py-8 text-2xl font-bold"> {{ number_format(Auth::user()->redeem_balance, 0) }}</h1>

                    <p class="px-2 text-lg">Redeemed Points</p>
                </div>
            </div>
            <div class="relative">
                <img class="absolute inset-0 w-full h-full" src="{{asset('images/account/promo-ad.png')}}" alt="">
                <div class="relative p-4 space-y-8">
                    <h1 class="text-sm text-[#cf000f] font-semibold">Free Shipping on Your Vitamin and Supplement Orders.</h1>

                    <h1 class="text-xl font-bold">Enjoy free shipping on <br> all vitamin and <br> supplement order <br> over ₱1,000.</h1>
                </div>
            </div>
        </div>
        <div>
            <div class="border border-[#cf000f] p-4 rounded-xl space-y-4 max-h-96 overflow-y-auto">
                <h1 class="font-semibold">Active Subscriptions</h1>
                @foreach ($subscriptions as $subscription_transactions)
                <div class="flex justify-between p-2 text-sm bg-gray-100">
                    <div>
                        <h1 class="font-bold">Subscription No. {{$subscription_transactions->id}}</h1>
                        <p class="text-gray-400">Next Delivery Date:</p>
                        <p class="text-gray-400">{{ $subscription_transactions->date_received }}</p>
                    </div>

                    <div>
                        <button
                            class="text-[#cf000f] toggleTransactions"
                            data-subscription-id="{{ $subscription_transactions->id }}">
                            View Transactions
                        </button>
                    </div>
                </div>

                <!-- Transactions list, initially hidden -->
                <div class="hidden p-2 space-y-2 overflow-y-auto transactions-list bg-gray-50 max-h-64" id="transactions-{{ $subscription_transactions->id }}">
                    @foreach ($subscription_transactions->transactions as $transaction)
                    <div class="flex justify-between p-2 text-sm bg-white rounded-md shadow-sm">
                        <div>
                            <p class="font-medium">Transaction ID: {{ $transaction->id }}</p>
                            <p class="text-gray-400">{{ $transaction->created_at->format('F d, Y') }}</p>
                        </div>
                        <button
                            class="text-[#cf000f] viewTransaction"
                            data-transaction-id="{{ $transaction->id }}">
                            View Details
                        </button>
                    </div>
                    @endforeach
                </div>
                @endforeach
            </div>

        </div>

        <script>
            // Toggle visibility of transactions
            document.querySelectorAll('.toggleTransactions').forEach(button => {
                button.addEventListener('click', function() {
                    const subscriptionId = this.dataset.subscriptionId;
                    const transactionList = document.getElementById(`transactions-${subscriptionId}`);
                    if (transactionList) {
                        transactionList.classList.toggle('hidden');
                    }
                });
            });
        </script>

    </div>
    <div class="py-8 space-y-4">
        <div class="flex flex-wrap items-center justify-between gap-4">
            <h1 class="text-xl font-semibold text-[#cf000f]">Recent Orders</h1>
            <div>
                <a href="{{url('purchase_history')}}">
                    <button class="text-[#cf000f] border border-[#cf000f] px-4 py-2 rounded-full">View My Purchase</button>
                </a>
            </div>

        </div>
        <div class="relative overflow-x-auto shadow-md sm:rounded-lg">
            <table class="w-full text-sm text-left text-gray-500 rtl:text-right ">
                <thead class="text-sm text-[#cf000f]  bg-gray-50 ">
                    <tr>
                        <th scope="col" class="p-3 text-nowrap">
                            Order Number
                        </th>
                        <th scope="col" class="px-6 py-3 ">
                            Date
                        </th>
                        <th scope="col" class="px-6 py-3">
                            Status
                        </th>
                        <th scope="col" class="px-6 py-3">
                            Order Total
                        </th>
                        <th scope="col" class="px-6 py-3">
                            Points
                        </th>
                        <th scope="col" class="px-6 py-3">
                            Courier
                        </th>
                        <th scope="col" class="px-6 py-3">
                            Shipping Fee
                        </th>
                        <th scope="col" class="px-6 py-3">
                            Uploaded Prescription
                        </th>
                        <th scope="col" class="px-6 py-3">
                            Discount Proof
                        </th>
                        <th scope="col" class="px-6 py-3">
                        </th>
                    </tr>
                </thead>
                <tbody>
                    @foreach ($orders->sortByDesc('created_at')->take(5) as $order)
                    <tr class="bg-white border-b hover:bg-gray-50">
                        <td class="w-4 p-4">
                            #{{ str_pad($order->id, 6, '0', STR_PAD_LEFT) }}
                        </td>
                        <th scope="row" class="px-6 py-4 font-medium text-gray-900 whitespace-nowrap">
                            {{ $order->created_at->format('F d, Y') }}
                        </th>
                        <td class="px-6 py-4">
                            {{ $order->status }}
                        </td>
                        <td>
                            ₱{{ number_format($order->total, 2) }}
                        </td>
                        <td class="px-6 py-4 text-nowrap">
                            {{ floor($order->total / 100) }} Points
                        </td>
                        <td class="text-nowrap">
                            {{$order->shipping ? $order->shipping->courier : "No courier yet"}}
                        </td>
                        <td class="px-6 py-4 text-nowrap">
                            {{$order->shipping ? $order->shipping->shipping_fee : "No shipping fee yet"}}
                        </td>
                        <td>
                            <div class="flex justify-center">
                                <img class="object-cover w-16 rounded-md" src="{{asset($order->upload_prescription)}}" alt="">
                            </div>
                        </td>
                        <td class="px-6 py-4">
                            <div class="flex justify-center">
                                <img class="object-cover w-16 rounded-md" src="{{asset($order->discount_proof)}}" alt="">
                            </div>
                        </td>
                        <td class="px-6 py-4">
                            <a href="#" class="text-sm font-medium text-[#cf000f] view-details text-nowrap"
                                data-order-id="{{ $order->id }}"
                                data-order-status="{{ $order->status }}"
                                data-order-payment="{{ $order->payment_method }}"
                                data-order-date="{{ $order->created_at->format('F d, Y') }}"
                                data-order-total="{{ number_format($order->total, 2) }}"
                                data-billing-info="{{ json_encode($order->billingInformation) }}"
                                data-order-details="{{ json_encode($order->orderDetails) }}"
                                data-order-courier="{{ $order->shipping ? $order->shipping->courier : 'No courier yet' }}"
                                data-order-shipping-fee="{{ $order->shipping ? $order->shipping->shipping_fee : 'No shipping fee yet' }}"
                                data-uploaded-prescription="{{ asset($order->upload_prescription) }}"
                                data-discount-proof="{{ asset($order->discount_proof) }}">View Details</a>

                        </td>
                    </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
    </div>

</div>
<div id="orderModal" class="fixed inset-0 z-50 flex items-center justify-center hidden bg-black bg-opacity-50">
    <div class="w-full sm:w-3/4 md:w-1/2 lg:w-1/2 p-4 sm:p-6 bg-white rounded-lg shadow-lg overflow-auto max-h-[90vh]">
        <button id="closeModal" class="absolute top-0 right-0 m-4 text-gray-500">&times;</button>
        <h2 class="mb-4 text-2xl font-semibold">Order Details</h2>
        <hr class="my-4">
        <div class="grid grid-cols-1 gap-4 sm:grid-cols-6">
            <div>
                <p><strong>Order ID:</strong> </p>
            </div>
            <div class="col-span-5"><span id="order-id"></span></div>

            <div>
                <p><strong>Date:</strong> </p>
            </div>
            <div class="col-span-5"><span id="order-date"></span></div>

            <div>
                <p><strong>Order Status:</strong> </p>
            </div>
            <div class="col-span-5"><span id="order-status"></span></div>

            <div>
                <p><strong>Payment Method:</strong> </p>
            </div>
            <div class="col-span-5"><span id="order-payment"></span></div>

            <div>
                <p><strong>Total:</strong> </p>
            </div>
            <div class="col-span-5"><span id="order-total"></span></div>

            <!-- Courier and Shipping Fee -->
            <div>
                <p><strong>Courier:</strong> </p>
            </div>
            <div class="col-span-5"><span id="order-courier"></span></div>

            <div>
                <p><strong>Shipping Fee:</strong> </p>
            </div>
            <div class="col-span-5"><span id="order-shipping-fee"></span></div>

            <!-- Uploaded Prescription and Discount Proof -->
            <div>
                <p><strong>Uploaded Prescription:</strong> </p>
            </div>
            <div class="col-span-5">
                <img id="uploaded-prescription" class="object-cover w-20 " alt="" />
            </div>

            <div>
                <p><strong>Discount Proof:</strong> </p>
            </div>
            <div class="col-span-5">
                <img id="discount-proof" class="object-cover w-20 " alt="" />
            </div>

            <div>
                <h3><strong>Shipping Address</strong></h3>

            </div>

            <div class="col-span-5">
                <div>
                    <span id="billing-name"></span><br>
                    <span id="billing-email"></span><br>
                    <span id="billing-phone_number"></span><br>
                    <span id="billing-street_address"></span><br>
                    <span id="billing-city"></span><br>
                    <span id="billing-state"></span><br>
                    <span id="billing-country"></span><br>
                    <span id="billing-zip_code"></span><br>
                </div>
            </div>
        </div>



        <hr class="my-4">

        <h3 class="mt-4 text-xl"><strong>Items in Order</strong></h3>

        <!-- Start Table for Order Details -->
        <div class="overflow-x-auto">
            <table class="min-w-full border-collapse table-auto">
                <thead>
                    <tr>
                        <th class="p-2 text-[#cf000f] text-start">Product Image</th>
                        <th class="p-2 text-[#cf000f] text-start">Price</th>
                        <th class="p-2 text-[#cf000f] text-start">Quantity</th>
                        <th class="p-2 text-[#cf000f] text-start">Subtotal</th>
                    </tr>
                </thead>
                <tbody id="order-details">
                    <!-- Each product will have its own row with an ID for name, quantity, price, and image -->
                    <tr id="product-1">
                        <td class="p-2 "><img id="product-image-1" src="" alt="Product Image" class="object-cover w-16 h-16"></td>
                        <td class="p-2 "><span id="product-quantity-1"></span></td>
                        <td class="p-2 ">₱<span id="product-price-1"></span></td>
                    </tr>
                    <!-- Repeat similar rows for other products (product-2, product-3, etc.) -->
                </tbody>
            </table>
        </div>
        <!-- End Table for Order Details -->
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Get modal and close button
        const orderModal = document.getElementById('orderModal');
        const closeModalButton = document.getElementById('closeModal');

        // Loop through each "View Details" link and add event listeners
        const viewDetailsLinks = document.querySelectorAll('.view-details');

        viewDetailsLinks.forEach(link => {
            link.addEventListener('click', function(e) {
                e.preventDefault();

                const orderId = link.getAttribute('data-order-id');
                const orderStatus = link.getAttribute('data-order-status');
                const payment = link.getAttribute('data-order-payment');
                const orderDate = link.getAttribute('data-order-date');
                const orderTotal = link.getAttribute('data-order-total');
                const billingInfo = JSON.parse(link.getAttribute('data-billing-info'));
                const orderDetails = JSON.parse(link.getAttribute('data-order-details'));
                const courier = link.getAttribute('data-order-courier');
                const shippingFee = link.getAttribute('data-order-shipping-fee');
                const uploadedPrescription = link.getAttribute('data-uploaded-prescription');
                const discountProof = link.getAttribute('data-discount-proof');

                // Populate modal with the data using IDs
                populateOrderModal(orderId, orderStatus, payment, orderDate, orderTotal, billingInfo, orderDetails, courier, shippingFee, uploadedPrescription, discountProof);

                // Show the modal
                orderModal.classList.remove('hidden');
            });
        });

        // Close the modal when close button is clicked
        closeModalButton.addEventListener('click', function() {
            orderModal.classList.add('hidden');
        });

        // Close the modal if clicked outside of it
        orderModal.addEventListener('click', function(e) {
            if (e.target === orderModal) {
                orderModal.classList.add('hidden');
            }
        });
    });

    // Function to populate the modal with order data using IDs
    function populateOrderModal(orderId, orderStatus, payment, orderDate, orderTotal, billingInfo, orderDetails, courier, shippingFee, uploadedPrescription, discountProof) {
        // Populate Order ID, Status, Date, and Total
        document.getElementById('order-id').textContent = `#${orderId}`;
        document.getElementById('order-status').textContent = orderStatus;
        document.getElementById('order-payment').textContent = payment;
        document.getElementById('order-date').textContent = orderDate;
        document.getElementById('order-total').textContent = `₱${orderTotal}`;

        // Populate Courier and Shipping Fee
        document.getElementById('order-courier').textContent = courier || "No courier yet";
        document.getElementById('order-shipping-fee').textContent = shippingFee || "No shipping fee yet";

        // Populate Uploaded Prescription and Discount Proof
        document.getElementById('uploaded-prescription').src = uploadedPrescription || 'default-image.jpg';
        document.getElementById('discount-proof').src = discountProof || 'default-image.jpg';

        // Populate Billing Information
        document.getElementById('billing-name').textContent = `${billingInfo.first_name} ${billingInfo.middle_name} ${billingInfo.last_name}`;
        document.getElementById('billing-email').textContent = billingInfo.email;
        document.getElementById('billing-phone_number').textContent = billingInfo.phone_number;
        document.getElementById('billing-street_address').textContent = billingInfo.street_address;
        document.getElementById('billing-city').textContent = billingInfo.city;
        document.getElementById('billing-state').textContent = billingInfo.state;
        document.getElementById('billing-country').textContent = billingInfo.country;
        document.getElementById('billing-zip_code').textContent = billingInfo.zip_code;

        // Populate Order Details (Products)
        const orderDetailsContainer = document.getElementById('order-details');
        orderDetailsContainer.innerHTML = ''; // Clear previous content

        orderDetails.forEach(detail => {
            const product = detail.product;
            const firstImage = product.images.length > 0 ? product.images[0].image : 'default-image.jpg';
            const totalPrice = (product.price * detail.quantity).toFixed(2);

            const row = document.createElement('tr');
            row.innerHTML = `
            <td class="px-4 py-2">
                <img src="${firstImage}" alt="" class="inline-block object-cover w-16 h-16">
                <span>${product.name}</span>
            </td>
            <td class="px-4 py-2">₱${product.price}</td>
            <td class="px-4 py-2">${detail.quantity}</td>
            <td class="px-4 py-2">₱${detail.subtotal}</td>
        `;
            orderDetailsContainer.appendChild(row);
        });
    }
</script>

<div id="transactionModal" class="fixed inset-0 flex items-center justify-center hidden bg-gray-800 bg-opacity-50">
    <div class="w-full max-w-3xl p-6 mx-4 bg-white rounded shadow-lg sm:mx-auto">
        <div class="flex items-start justify-between">
            <h2 class="mb-4 text-lg font-bold">Transaction Details</h2>
            <button id="closetransactionModal" class="px-4 py-2 text-red-500 rounded"><i class='bx bx-x'></i></button>
        </div>
        <div id="modalContent" class="text-sm overflow-auto max-h-[75vh]">
            <!-- Dynamic Content will be injected here -->
        </div>

        <div class="flex mt-4">
            <form id="paymentForm" method="POST" action="{{ route('process.billing.payment') }}" class="w-full">
                @csrf
                <div class="flex items-center justify-between">
                    <div>
                        <label for="payment_method">Select Payment Method:</label>
                        <div>
                            <label for="gcash">
                                <input type="radio" id="gcash" name="payment_method" value="gcash" required>
                                GCash
                            </label>
                        </div>
                        <div>
                            <label for="card">
                                <input type="radio" id="card" name="payment_method" value="card" required>
                                Credit/Debit Card
                            </label>
                        </div>
                    </div>
                    <div>
                        <input type="hidden" name="order_id" id="orderId">
                        <button type="submit" class="px-4 py-2 text-white bg-green-500 rounded">Proceed to Payment</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>


<script>
    document.addEventListener("DOMContentLoaded", () => {
        const transactionModal = document.getElementById("transactionModal");
        const modalContent = document.getElementById("modalContent");
        const paymentForm = document.getElementById("paymentForm");
        const orderIdInput = document.getElementById("orderId");

        function openTransactionModal(transactionId) {
            fetch(`public/transactions/${transactionId}`)
                .then(response => response.json())
                .then(data => {
                    const numberFormatter = new Intl.NumberFormat('en-PH', {
                        style: 'currency',
                        currency: 'PHP',
                    });
                    modalContent.innerHTML = `
                    <p><strong>Transaction ID:</strong> ${data.transaction.id}</p>
                    <p><strong>Total:</strong> ${numberFormatter.format(data.transaction.total)}</p>
                    <p><strong>Payment Status:</strong> ${data.transaction.payment_status}</p>
                    <p><strong>Note:</strong> ${data.transaction.note || "N/A"}</p>
                    <h3 class="mt-4 text-lg font-bold">Transaction Details</h3>
                    <table class="w-full mt-2 border border-collapse border-gray-300">
                        <thead>
                            <tr class="bg-gray-100">
                                <th class="px-4 py-2 border">Product</th>
                                <th class="px-4 py-2 border">Quantity</th>
                                <th class="px-4 py-2 border">Subtotal</th>
                            </tr>
                        </thead>
                        <tbody>
                            ${data.details
                                .map(detail => `
                                    <tr>
                                        <td class="px-4 py-2 border">${detail.product.name}</td>
                                        <td class="px-4 py-2 border">${detail.quantity}</td>
                                        <td class="px-4 py-2 border">${numberFormatter.format(detail.subtotal)}</td>
                                    </tr>
                                `)
                                .join("")}
                        </tbody>
                    </table>
                    `;
                    orderIdInput.value = data.transaction.id; // Set order_id for the form
                    // Hide payment form if payment_status is Paid
                    if (data.transaction.payment_status === "Paid") {
                        paymentForm.classList.add("hidden");
                    } else {
                        paymentForm.classList.remove("hidden");
                    }
                    transactionModal.classList.remove("hidden");
                })
                .catch(error => console.error("Error fetching transaction details:", error));

        }

        document.querySelectorAll(".viewTransaction").forEach(button => {
            button.addEventListener("click", () => {
                const transactionId = button.dataset.transactionId;
                openTransactionModal(transactionId);
            });
        });

        document.getElementById("closetransactionModal").addEventListener("click", () => {
            transactionModal.classList.add("hidden");
        });

    });
</script>


@include('layouts.footer')
@endsection