<!-- contact_us.blade.php -->
@extends('layouts.main-app')

@section('title', 'OTP')

@section('content')

@include('layouts.navbar')
<form action="{{ route('otp.verify') }}" method="POST">
    @csrf
    <div class="bg-gray-100">
        <div class="container max-w-screen-md px-4 py-8 mx-auto">
            <h1 class="text-[#cf000f] font-bold text-center pb-8 text-2xl">Verify your Account</h1>
            @if ($errors->any())
            <div class="p-4 mb-4 text-white bg-red-500 rounded">
                <ul>
                    @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
            @endif
            <div class="flex flex-col justify-between col-span-2 bg-white md:flex-row rounded-3xl">

                <div class="flex flex-col p-8 space-y-2">
                    <h1 class="pb-8 font-bold text-black">A One-Time Password (OTP) has been sent to your registered email.</h1>
                    <div>
                        <label for="otp1">Please enter the 6-digit OTP sent to [your email]</label>
                        <input maxlength="6" required type="text" name="otp1" class="border border-[#cf000f] w-full rounded-full  p-2" placeholder="Enter OTP code">
                    </div>
                    <div>
                        <button class="bg-[#cf000f] text-white w-full rounded-full py-2" type="submit">Verify</button>
                    </div>
                    <div class="text-center text-gray-500">
                        Didn't receive the code?
                    </div>
                    <div id="resend-container" class="text-center text-gray-500">
                        <button id="resend-btn" class="text-[#cf000f] font-bold" onclick="resendOtp()" disabled>
                            Resend OTP
                        </button>
                        <span id="timer" class="font-normal">in <span id="countdown">01:00</span></span>
                    </div>
                </div>
                <div>
                    <img class="object-cover w-full h-full rounded-r-2xl" src="{{asset('images/shop/img-login.png')}}" alt="">
                </div>
            </div>
        </div>
    </div>
</form>
<script>
    let countdownTime = 60;
    const countdownElement = document.getElementById('countdown');
    const resendButton = document.getElementById('resend-btn');

    function startCountdown() {
        resendButton.disabled = true;
        const timer = setInterval(() => {
            countdownTime--;
            const minutes = String(Math.floor(countdownTime / 60)).padStart(2, '0');
            const seconds = String(countdownTime % 60).padStart(2, '0');
            countdownElement.textContent = `${minutes}:${seconds}`;

            if (countdownTime <= 0) {
                clearInterval(timer);
                countdownElement.textContent = '';
                resendButton.disabled = false;
            }
        }, 1000);
    }

    async function resendOtp() {
        resendButton.disabled = true;
        countdownTime = 60;
        startCountdown();

        try {
            const response = await fetch('{{ route("otp.resend") }}', {
                method: 'POST',
                headers: {
                    'X-CSRF-TOKEN': '{{ csrf_token() }}',
                    'Content-Type': 'application/json',
                },
            });
            const result = await response.json();
            if (result.success) {
                alert(result.message);
            } else {
                alert('Failed to resend OTP.');
            }
        } catch (error) {
            alert('An error occurred while resending OTP.');
        }
    }

    // Start initial countdown on page load
    document.addEventListener('DOMContentLoaded', startCountdown);
</script>


@include('layouts.footer')
@endsection