<?php

use App\Http\Controllers\AboutUsImageController;
use App\Models\Order;
use App\Models\Subscription;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\CartController;
use App\Http\Controllers\PageController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\BlogsController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\BannerController;
use App\Http\Controllers\BillingController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\VoucherController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\PasswordController;
use App\Http\Controllers\ShippingController;
use App\Http\Controllers\WishlistController;
use App\Http\Controllers\ContactUsController;
use App\Http\Controllers\NewsletterController;
use App\Http\Controllers\SubscriptionController;
use App\Http\Controllers\VerificationController;
use Symfony\Component\HttpKernel\Profiler\Profile;
use App\Http\Controllers\Auth\AuthenticatedSessionController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', [PageController::class, 'home']);
Route::get('/about_us', [PageController::class, 'about_us']);
Route::get('/shop', [PageController::class, 'shop']);
Route::get('/product_details/{id}', [PageController::class, 'product_details']);
Route::get('/blogs', [PageController::class, 'blogs']);
Route::get('/blogs_details/{id}', [PageController::class, 'blogs_details']);
Route::get('/contact_us', [PageController::class, 'contact_us']);
Route::get('/cart', [PageController::class, 'cart']);
Route::get('/cart_login', [PageController::class, 'cart_login']);
Route::get('/login', [PageController::class, 'login']);
Route::get('/forgot_password', [PageController::class, 'forgot_password']);
Route::post('/forgot-password', [PasswordController::class, 'sendOtp'])->name('send.otp');
Route::get('/verify', [PageController::class, 'verify']);
Route::get('/new_password', [PageController::class, 'new_password'])->name('new_password');
Route::get('/register', [PageController::class, 'register']);
Route::post('/cart/store', [CartController::class, 'store'])->name('cart.store');
Route::get('/cart/remove/{product}', [CartController::class, 'remove'])->name('cart.remove');
Route::post('/otp', [PasswordController::class, 'verifyOtp'])->name('otp.verify');
Route::post('/password-reset', [PasswordController::class, 'updatePassword'])->name('passwords.updates');
Route::post('/otp/resend', [PasswordController::class, 'resend'])->name('otp.resend');
Route::post('/save-form', [ContactUsController::class, 'store'])->name('save.form');
Route::post('/save-newsletter', [NewsletterController::class, 'store'])->name('save.newsletter');
Route::post('/register', [UserController::class, 'register'])->name('register.submit');
Route::post('login', [AuthenticatedSessionController::class, 'store'])->name('login.submit');
Route::post('/cart/saveCheckoutData', [CartController::class, 'saveCheckout'])->name('checkout.save');


Route::middleware('auth')->group(function () {
    Route::get('/wishlist', [PageController::class, 'wishlist']);
    Route::get('/user_dashboard', [PageController::class, 'user_dashboard'])->name('user_dashboard');
    Route::get('/purchase_history', [PageController::class, 'purchase_history']);
    Route::get('/user_profile', [PageController::class, 'user_profile']);
    Route::get('/change_password', [PageController::class, 'change_password']);
    Route::get('/payment_methods', [PageController::class, 'payment_methods']);
    Route::post('/update_user_profile', [UserController::class, 'update'])->name('user_profile.update');
    Route::get('/rewards', [PageController::class, 'rewards']);
    Route::get('/subscription', [PageController::class, 'subscription']);
    Route::post('/update-password', [UserController::class, 'updatePassword'])->name('user_profile.update_password');
    Route::post('/add_wishlist/{product_id}/{customer_id}', [WishlistController::class, 'store'])->name('wishlist.store');
    Route::delete('/wishlist/{id}', [WishlistController::class, 'destroy'])->name('wishlist.destroy');
    Route::get('/place_order', [PageController::class, 'place_order'])->name('place_order');
    Route::post('/billing/submit', [BillingController::class, 'processBillingAndPayment'])->name('submit.billing');
    Route::get('/payment/verify', [BillingController::class, 'verify'])->name('payment.verify');
    Route::get('/success/{id}', [PageController::class, 'success'])->name('order.success');
    Route::post('/redeem-points', [BillingController::class, 'redeemPoints'])->name('redeem.points');
    Route::post('/validate-voucher', [VoucherController::class, 'validateVoucher'])->name('validate.voucher');
    Route::post('/subscriptions', [SubscriptionController::class, 'store'])->name('subscriptions.store');
    Route::get('public/transactions/{id}', [SubscriptionController::class, 'getTransactionDetails']);
    Route::post('/subscription-billing/submit', [SubscriptionController::class, 'processBillingAndPayment'])->name('process.billing.payment');
    Route::get('/subscription-billing/verify', [SubscriptionController::class, 'verify'])->name('subscription.billing.verify');
});

Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::post('public/admin/products/update-availability/{id}', [ProductController::class, 'updateAvailability'])->name('products.update-availability');
Route::post('public/admin/products/update-featured/{id}', [ProductController::class, 'updateFeatured'])->name('products.update-featured');

Route::middleware('auth')->prefix('admin')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
    Route::resource('/banners', BannerController::class);
    Route::resource('/shipping', ShippingController::class);
    Route::resource('/category', CategoryController::class);
    Route::resource('/blogs', BlogsController::class);
    Route::resource('/contactus', ContactUsController::class);
    Route::resource('/newsletter', NewsletterController::class);
    Route::resource('/products', ProductController::class);
    Route::resource('/orders', OrderController::class);
    Route::resource('/voucher', VoucherController::class);
    Route::resource('/subscriptions', SubscriptionController::class);
    Route::resource('/about_us_image', AboutUsImageController::class);
    Route::get('/create/{id}', [SubscriptionController::class, 'create_transaction'])->name('subscriptions.create.transaction');
    Route::get('/show_transaction/{id}', [SubscriptionController::class, 'show_transaction_details'])->name('subscriptions.show_transaction_details');
    Route::delete('/delete-transaction/{id}', [SubscriptionController::class, 'destroy_transaction'])->name('subscriptions.destroy.transaction');
    Route::post('/subscription-transaction', [SubscriptionController::class, 'store_transaction'])->name('subscription.transaction.store');
    Route::get('/subscription/transaction/{transaction}/edit', [SubscriptionController::class, 'edit'])->name('subscription.transaction.edit');
    Route::put('/subscription/transaction/{transaction}', [SubscriptionController::class, 'update'])->name('subscription.transaction.update');
    Route::get('/subscription/transaction/{transaction}/edit', [SubscriptionController::class, 'edit'])->name('subscription.transaction.edit');
    Route::get('/subscriptions/edit/{id}', [SubscriptionController::class, 'edit_subscription'])->name('edit.subscriptions');
    Route::put('/subscriptions/update/{id}', [SubscriptionController::class, 'update_subscription'])->name('update.subscriptions');
});

require __DIR__ . '/auth.php';
