<div class="h-[26rem] group hover:shadow-xl hover:bg-white group-regular-product-<?php echo e($product->id); ?>">
    <a href="<?php echo e(url('product_details', $product->id)); ?>">
        <div class="flex flex-col">
             <img class="object-contain p-4 bg-white h-60 w-full" 
            src="<?php echo e($product->images->isNotEmpty() ? asset($product->images->first()->image) : asset('images/default-placeholder.jpg')); ?>" 
            alt="">
            <div class="px-2 ">
                <div class="flex justify-center items-center w-full ">
                    <div class="grid grid-cols-4 w-full max-w-xl">
                        <div class="col-span-3">
                           <h1 class="text-sm truncate w-full max-w-full" title="<?php echo e($product->name); ?>">
                                <?php echo e($product->name); ?>

                            </h1>
                        </div>
                        <div class="flex justify-center ">
                            <?php if(Auth::check()): ?>
                                <button onclick="addToWishlist(<?php echo e($product->id); ?>)" class="focus:outline-none">
                                    <img src="<?php echo e(asset('images/homepage/icon-addtowishlist.webp')); ?>" alt="Add to Wishlist">
                                </button>
                            <?php else: ?>
                                <a href="<?php echo e(url('wishlist')); ?>">
                                    <button type="button" class="focus:outline-none">
                                        <img src="<?php echo e(asset('images/homepage/icon-addtowishlist.webp')); ?>" alt="Add to Wishlist">
                                    </button>
                                </a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>

                <p class="font-bold text-[#cf000f]">₱<?php echo e(number_format($product->price, 2)); ?></p>
            </div>
        </div>
    </a>

    <div class="flex flex-col items-center hidden py-2 space-y-2 group-hover:flex">
        <input type="hidden" id="product-id-<?php echo e($product->id); ?>" value="<?php echo e($product->id); ?>">
        <input type="hidden" id="quantity-<?php echo e($product->id); ?>" value="1">

        <!-- Quantity controls -->
        <div class="flex items-center justify-center space-x-2">
            <button type="button" class="border border-[#cf000f] rounded-full text-[#cf000f] h-8 w-8 bg-white" onclick="decrementQuantity(<?php echo e($product->id); ?>)">-</button>
            <span id="quantity-display-<?php echo e($product->id); ?>" class="px-4">1</span>
            <button type="button" class="border border-[#cf000f] rounded-full text-[#cf000f] h-8 w-8 bg-white" onclick="incrementQuantity(<?php echo e($product->id); ?>)">+</button>
        </div>

        <!-- Add to Cart Button -->
        <button type="button" onclick="addToCart(<?php echo e($product->id); ?>)" class="bg-[#cf000f] text-white flex justify-between items-center rounded-full px-6 py-2 text-xs group-hover:flex">
            Add to Cart<img class="pl-4" src="<?php echo e(asset('images/homepage/icon-addtocart.webp')); ?>" alt="Add to Cart">
        </button>
    </div>
</div>

<script>
    function incrementQuantity(productId) {
        const quantityInput = document.getElementById(`quantity-${productId}`);
        const quantityDisplay = document.getElementById(`quantity-display-${productId}`);
        let quantity = parseInt(quantityInput.value);

        quantity++;
        quantityInput.value = quantity;
        quantityDisplay.textContent = quantity;
    }

    function decrementQuantity(productId) {
        const quantityInput = document.getElementById(`quantity-${productId}`);
        const quantityDisplay = document.getElementById(`quantity-display-${productId}`);
        let quantity = parseInt(quantityInput.value);

        if (quantity > 1) { // Optional: Prevent quantity from going below 1
            quantity--;
            quantityInput.value = quantity;
            quantityDisplay.textContent = quantity;
        }
    }

    function addToCart(productId) {
        const quantity = document.getElementById(`quantity-${productId}`).value;
        const productIdElement = document.getElementById(`product-id-${productId}`).value;

        // Example of adding to cart via an AJAX request
        fetch("<?php echo e(route('cart.store')); ?>", {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-CSRF-TOKEN': '<?php echo e(csrf_token()); ?>'
            },
            body: JSON.stringify({
                product_id: productIdElement,
                quantity: quantity
            })
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                // Display modal with success message
                showModal('Product added to cart!', 'Thank you for adding to your cart.', '');
            } else {
                // Display modal with error message
                showModal('Something went wrong!', 'Please try again later.', '');
            }
        });
    }

    function addToWishlist(productId) {
        // Get the logged-in user's customer ID
        const customerId = <?php echo e(Auth::check() ? Auth::user()->id : 'null'); ?>;
        
        if (customerId === null) {
            alert('You must be logged in to add items to your wishlist.');
            return;
        }
    
        // Add to wishlist via AJAX
        fetch("<?php echo e(url('add_wishlist')); ?>/" + productId + "/" + customerId, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-CSRF-TOKEN': '<?php echo e(csrf_token()); ?>'
            },
            body: JSON.stringify({
                product_id: productId,
                customer_id: customerId
            })
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                // Display modal with success message
                showModal('Product added to wishlist!', 'Thank you for adding to your wishlist.', 'You can view it anytime in your wishlist!');
            } else {
                // Display modal with error message
                showModal('Something went wrong!', 'Please try again later.', '');
            }
        });
    }
    
    function showModal(message1, message2, message3) {
        // Set the modal content
        const successModal = document.getElementById('successModal');
        successModal.querySelector('p:nth-child(2)').textContent = message1;
        successModal.querySelector('p:nth-child(3)').textContent = message2;
        successModal.querySelector('p:nth-child(4)').textContent = message3;
    
        // Show the modal
        successModal.style.display = 'flex';
    
        // Auto close after 5 seconds
        setTimeout(closeModal, 5000);
    }
    
    function closeModal() {
        document.getElementById('successModal').style.display = 'none';
    }
</script>
<?php /**PATH /home/rwebserver/public_html/gardose/resources/views/layouts/product.blade.php ENDPATH**/ ?>